"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PaginationOptions = void 0;
const react_1 = __importDefault(require("react"));
const react_bootstrap_1 = require("react-bootstrap");
const object_1 = require("../helpers/object");
const DatatableWrapper_1 = require("./DatatableWrapper");
/**
 * Renders a control for the pagination options. It will show a form group, consisting of
 * a select input, as well as a label/text before and after the input. By default,
 * it renders "Rows per page" as a label, which refers to the select input. There is no
 * text after the select input, unless specified in the `labels.afterSelect` prop.
 *
 * The options available in the select input are the ones specified from the `DatatableWrapper`,
 * or the ones passed in this component's prop `controlledProps.rowsPerPageOptions`.
 *
 * When `alwaysShowPagination` is set to `false`, then this component will be visually hidden.
 */
function PaginationOptions({ labels, classes, alwaysShowPagination = true, controlledProps }) {
    const { onRowsPerPageChange: onRowsPerPageChangeContext, rowsPerPageOptions: rowsPerPageOptionsContext, rowsPerPageState: rowsPerPageStateContext, filteredDataLength: filteredDataLengthContext } = (0, DatatableWrapper_1.useDatatableWrapper)();
    // Controlled has the bigger priority.
    const rowsPerPageOptions = (controlledProps === null || controlledProps === void 0 ? void 0 : controlledProps.rowsPerPageOptions) || rowsPerPageOptionsContext;
    const rowsPerPageState = (controlledProps === null || controlledProps === void 0 ? void 0 : controlledProps.rowsPerPage) || rowsPerPageStateContext;
    const filteredDataLength = (controlledProps === null || controlledProps === void 0 ? void 0 : controlledProps.filteredDataLength) || filteredDataLengthContext;
    const onRowsPerPageChange = (controlledProps === null || controlledProps === void 0 ? void 0 : controlledProps.onRowsPerPageChange) || onRowsPerPageChangeContext;
    // Hide pagination if pagination is meant to not always be shown or
    // if the filtered data length is less than the minimum rows per page option.
    const hidePaginationOptions = !alwaysShowPagination &&
        filteredDataLength <= Math.min(...rowsPerPageOptions);
    return (react_1.default.createElement(react_bootstrap_1.Form.Group, { controlId: "formGroupPagination", className: (0, object_1.makeClasses)('paginationOpts__root', classes === null || classes === void 0 ? void 0 : classes.formGroup, {
            invisible: hidePaginationOptions
        }) },
        react_1.default.createElement(react_bootstrap_1.Form.Label, { className: classes === null || classes === void 0 ? void 0 : classes.formText }, (labels === null || labels === void 0 ? void 0 : labels.beforeSelect) || 'Rows per page'),
        react_1.default.createElement(react_bootstrap_1.Form.Select, { name: "table-pagination-options", value: rowsPerPageState, as: "select", placeholder: "select", onChange: (e) => onRowsPerPageChange(Number(e.target.value)), className: classes === null || classes === void 0 ? void 0 : classes.formControl }, rowsPerPageOptions.map((option) => {
            const optionProps = {
                key: `page-opt-${option}`,
                value: option
            };
            return react_1.default.createElement("option", Object.assign({}, optionProps), option);
        })),
        (labels === null || labels === void 0 ? void 0 : labels.afterSelect) && (react_1.default.createElement(react_bootstrap_1.Form.Text, { className: classes === null || classes === void 0 ? void 0 : classes.formText }, labels === null || labels === void 0 ? void 0 : labels.afterSelect))));
}
exports.PaginationOptions = PaginationOptions;
